@@ -15,7 +15,7 @@ def config_from_environment(env_prefix, env_required=None, **kwargs):
     for env_key, value in os.environ.items():
         env_key = env_key.upper()
         if env_key.startswith(prefix):
-            key = '_'.join(env_key.split('_')[1:]).lower()
+            key = env_key[len(prefix):].lower()
             config[key] = env_eval(value)
     if env_required:
         for required in env_required:
